@@ -1,19 +1,7 @@
 /*
- *   Copyright (C) 2003 Waldo Bastian <bastian@kde.org>
+ *   SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -183,8 +171,7 @@ void MenuFolderInfo::save(MenuFile *menuFile)
 {
     if (s_deletedApps) {
         // Remove hotkeys for applications that have been deleted
-        for (QStringList::ConstIterator it = s_deletedApps->constBegin();
-             it != s_deletedApps->constEnd(); ++it) {
+        for (QStringList::ConstIterator it = s_deletedApps->constBegin(); it != s_deletedApps->constEnd(); ++it) {
             // The shorcut is deleted if we set a empty sequence
             GlobalAccel::changeMenuEntryShortcut(KService::serviceByStorageId(*it), QKeySequence());
         }
